/*
 * An implementation of  for this problem: http://www.spoj.com/problems/FACT0/
 * For more information about this implementation see http://www.giaithuatlaptrinh.com/?p=34
 *  Created on: Jul 19, 2015
 *      Author: hunglv
 */
#include<stdio.h>
#include<iostream>
#include<stdlib.h>
#include<math.h>
#include<stack>
#include<string.h>

using namespace std;
#define MAX 1000007
#define PRIME 1
#define COMPOSITE 0
#define NULL 0

typedef unsigned long long int LLU;

struct factor {
  LLU val;
  int count;
  struct factor *next;
};
struct factor *head;// the pointer to the head of the factor list
struct factor *curr; // the pointer to the end of the factor list


int miller_rabin_testing(int acc, LLU N);
LLU gcd(LLU a, LLU b);
int witness(LLU a,  LLU N);
void decompose(LLU p, int *k, LLU *m);
LLU random64();
LLU mod_mul(LLU a, LLU b, LLU p);
LLU mod_power(LLU a, LLU b, LLU p);
void add_factor(LLU val);
void FastNativeFact(LLU N);
void print_factors();
LLU llu_fsqrt(LLU N);

int main() {

	LLU N;
	cin >> N;
	while(N != 0){
		head = (factor *)malloc( sizeof(struct factor));
		head->val = 0;
		head->next = NULL;
		curr = head;
		FastNativeFact(N);
		print_factors();
		printf("\n");
		cin>>N;
	}

}

void FastNativeFact(LLU N){
	while (N % 2 == 0){
		add_factor((LLU)2);
		N = N/2;
	}
	while (N % 3 == 0){
		add_factor((LLU)3);
		N = N/3;
	}
	if(N == 1) return;
	else if(miller_rabin_testing(10, N) == PRIME ){
		add_factor(N);
		return;
	}
	LLU Q = 5;
	int diff = 2;
	LLU uplim = llu_fsqrt(N);
	while(Q <= uplim){ // uplim = sqrt(N)
		if(N %Q == 0){
			add_factor(Q);
			N = N/Q;
			uplim = llu_fsqrt(N);
			if(miller_rabin_testing(10, N) == PRIME ){
				add_factor(N);
				return;
			}
		}else {
			Q = Q + (LLU)diff;
			diff = (diff&2) + 2;// diff is alternate between 2 and 4
		}
	}
}

void add_factor(LLU val){
	if(curr->val == val){
		curr->count++;
	}else if(curr->val == 0){
		curr->val = val;
		curr->count = 1;
	}else{
		factor *next = (factor*)malloc(sizeof(struct factor));
		next->val = val;
		next->count = 1;
		next->next = NULL;
		curr->next = next;
		curr = curr->next;
	}
}
void print_factors(){
	struct factor *it = head;
	while(it->next != NULL){
		printf("%llu^",it->val);
		printf("%d ", it->count);
		it = it->next;
	}
	printf("%llu^",it->val);
	printf("%d", it->count);
}
int miller_rabin_testing(int acc, LLU N){
	LLU a = 0;
	for(int i = 0; i <= acc; i++){
		a = random64()%(N-2)+ 2;
		if(gcd(a,N) != 1){
			return COMPOSITE;
		} else if (mod_power(a,N-1,N) != 1){
			return COMPOSITE;
		}else {
			if (witness(a,N) == COMPOSITE){
				return COMPOSITE;
			}
		}
	}
	return PRIME;
}

LLU gcd(LLU a, LLU b){
	LLU tmp;
	while  (b != 0){
		tmp  = b;
		b = a % b;
		a = tmp;
	}
	return a;
}

LLU mod_power(LLU a, LLU b, LLU p){
	if(b == 0) return 1;
	else if (b == 1){
		return a %p;
	} else {
		LLU x = mod_power(a, b/2, p);
		if((b& 1) == 0){ // b is even
			return mod_mul(x,x,p); // return  (x*x)%p;
		} else {
			return (mod_mul(mod_mul(x,x,p), a, p));// return (x*x*a)%p;
		}
	}
}
/*
 * this function compute (a*b) \mod p using (\log_2a + 1) space
 */

LLU mod_mul(LLU a, LLU b, LLU p){
	if (b == 1){
		return a %p;
	} else {
		LLU x = mod_mul(a, b/2, p);
		if((b& 1) == 0){ // b is even
			return (x+x)%p;
		} else {
			return (((x+x)%p)+a)%p;
		}
	}
}


int witness(LLU a,  LLU N){
	LLU m;
	int k;
	decompose(N-1,&k,&m);
	LLU B[k+1];
	B[0] = mod_power(a,m,N);
	if(B[0] == 1){
		return PRIME;
	} else {
		int i = 1;
		while(i <= k){
			B[i] =  mod_mul(B[i-1],B[i-1],N);// (B[i-1]*B[i-1])%N;
			if(B[i] == 1){
				if(B[i-1] == N-1){
					return PRIME;
				} else {
					return COMPOSITE;
				}
			}
			i++;
		}
	}
	return COMPOSITE;
}

void decompose(LLU p, int *k, LLU *m){
	int i = 0;
	while ((p& 1) == 0){ // p is even
		i++;
		p = p >> 1; // p = p /2
	}
	*k = i;
	*m = p;
}
/*
 * generating a random 64 bit number
 */
LLU random64(){
	LLU n  = 0;
	int l = rand()%(RAND_MAX-2)+2;
	int r = rand()%(RAND_MAX) + rand()%2;
	n = n | ((LLU)r);
	n = n << 32;
	n = n | ((LLU)l);
	return n;
}

/*
 * An implementation of the function that returns the floor of the square root of an integer
 * See http://www.giaithuatlaptrinh.com/?p=402 for details
 */

LLU llu_fsqrt(LLU  N){
	LLU X, A2, R;
	X = N;
	A2 = ((LLU)1) << 62;
	R = 0;
	while(N < A2){
		A2 >>= 2;
	}
	while(A2 > 0){
		if (X >= R + A2) {
			X -= R + A2;
			R = (R >> 1) + A2;
			A2 = A2>> 2;
		} else {
			A2 = A2 >> 2;
			R = R >> 1;
		}
	}
	return R;
}

